# Nēnē: A no-frills static site generator

[![Latest release on PyPI](https://img.shields.io/pypi/v/nene.svg?style=flat-square)][pypi]
[![Latest release on conda-forge](https://img.shields.io/conda/vn/conda-forge/nene.svg?style=flat-square)][conda-forge]
[![Compatible Python versions](https://img.shields.io/pypi/pyversions/nene.svg?style=flat-square)][pypi]

> Do you love <a href="https://github.com/getpelican">Pelican</a>?
> Can't get enough of that <a href="https://jekyllrb.com/">Jekyll</a>?
> Then Nēnē is probably not for you.

Static website generators seem to be the favourite pastime of developers
procrastinating on other more important projects.
So of course, I had to make my own!

When I say *no-frills*, I mean it. Nēnē has no built-in templates, no special
provisions for blogging, plugins, or the sort of thing that would be useful if
you just want to start a website.
But it also tries to combine several nice features from other generators into
something that will appeal to those who want to build their own templates.

> **Trivia:** *Nēnē* continues the long tradition of naming static site
> generators built in Python after birds (the nēnē is a
> [goose endemic to Hawai'i][nene-goose]).

## Documentation

Install instructions and other information can be found in the preliminary
documentation website (built with Nēnē, of course):
[nene.leouieda.com](https://nene.leouieda.com)

Looking for an example? Checkout these websites built with Nēnē:

* https://www.compgeolab.org ([source code](https://github.com/compgeolab/website))
* https://www.acarolcolombo.com ([source code](https://github.com/acarolcolombo/website))
* https://aguspesce.github.io/garabatos ([source code](https://github.com/aguspesce/garabatos))
* https://www.leouieda.com ([source code](https://github.com/leouieda/website))

**WARNING**: You probably want to pin Nēnē to a specific version since I will
likely break compatibility between releases.

## License

Nēnē is free and open-source software distributed under the
[MIT License](LICENSE.txt).

[nene-goose]: https://www.nps.gov/havo/learn/nature/nene.htm
[pypi]: https://pypi.org/project/nene/
[conda-forge]: https://github.com/conda-forge/nene-feedstock
